@@ -8,7 +8,8 @@ from pkg_resources import resource_filename
 __all__ = [
     'load_cdnow',
     'load_transaction_data',
-    'load_summary_data_with_monetary_value'
+    'load_summary_data_with_monetary_value',
+    'load_donations'
 ]
 
 
@@ -25,6 +26,10 @@ def load_dataset(filename, **kwargs):
     return pd.read_csv(resource_filename('lifetimes', 'datasets/' + filename), **kwargs)
 
 
+def load_donations(**kwargs):
+    return load_dataset('donations.csv', **kwargs)
+
+
 def load_cdnow(**kwargs):
     return load_dataset('cdnow_customers.csv', **kwargs)
 
@@ -51,4 +56,4 @@ def load_summary_data_with_monetary_value(**kwargs):
     df = load_dataset('cdnow_customers_transactions.csv', **kwargs)
     df.columns = ['customer_id', 'frequency', 'recency', 'T', 'monetary_value']
     df = df.set_index('customer_id')
-    return df
\ No newline at end of file
+    return df
